@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 __copyright__ = """
 Copyright (C) 2009-2017 Andreas Kloeckner
 Copyright (C) 2014-2017 Aaron Meurer
@@ -26,18 +24,15 @@ THE SOFTWARE.
 """
 
 
-NUM_VERSION = (2019, 2)
+from pudb.settings import load_config
+
+
+NUM_VERSION = (2021, 1)
 VERSION = ".".join(str(nv) for nv in NUM_VERSION)
 __version__ = VERSION
 
-from pudb.py3compat import raw_input, PY3
 
-from pudb.settings import load_config, save_config
-CONFIG = load_config()
-save_config(CONFIG)
-
-
-class PudbShortcuts(object):
+class PudbShortcuts:
     @property
     def db(self):
         import sys
@@ -59,12 +54,8 @@ class PudbShortcuts(object):
         dbg.set_trace(sys._getframe().f_back, paused=False)
 
 
-if PY3:
-    import builtins
-    builtins.__dict__["pu"] = PudbShortcuts()
-else:
-    import __builtin__
-    __builtin__.__dict__["pu"] = PudbShortcuts()
+import builtins
+builtins.__dict__["pu"] = PudbShortcuts()
 
 
 CURRENT_DEBUGGER = []
@@ -72,27 +63,14 @@ CURRENT_DEBUGGER = []
 
 def _tty_override():
     import os
-    return os.environ.get('PUDB_TTY')
+    return os.environ.get("PUDB_TTY")
 
 
 def _open_tty(tty_path):
     import io
     import os
-    import sys
-    if sys.version_info[0] == 2:
-        import fcntl
-        import termios
-        import struct
-        tty_file = open(tty_path, 'r+b', buffering=0)
-        try:
-            s = struct.unpack('hh', fcntl.ioctl(
-                tty_file.fileno(), termios.TIOCGWINSZ, '1234'))
-            term_size = (s[1], s[0])
-        except Exception:
-            term_size = None
-    else:
-        tty_file = io.TextIOWrapper(open(tty_path, 'r+b', buffering=0))
-        term_size = os.get_terminal_size(tty_file.fileno())
+    tty_file = io.TextIOWrapper(open(tty_path, "r+b", buffering=0))
+    term_size = os.get_terminal_size(tty_file.fileno())
 
     return tty_file, term_size
 
@@ -100,11 +78,11 @@ def _open_tty(tty_path):
 def _get_debugger(**kwargs):
     if not CURRENT_DEBUGGER:
         tty_path = _tty_override()
-        if tty_path and ('stdin' not in kwargs or 'stdout' not in kwargs):
+        if tty_path and ("stdin" not in kwargs or "stdout" not in kwargs):
             tty_file, term_size = _open_tty(tty_path)
-            kwargs.setdefault('stdin', tty_file)
-            kwargs.setdefault('stdout', tty_file)
-            kwargs.setdefault('term_size', term_size)
+            kwargs.setdefault("stdin", tty_file)
+            kwargs.setdefault("stdout", tty_file)
+            kwargs.setdefault("term_size", term_size)
 
         from pudb.debugger import Debugger
         dbg = Debugger(**kwargs)
@@ -115,12 +93,22 @@ def _get_debugger(**kwargs):
         return CURRENT_DEBUGGER[0]
 
 
+def _have_debugger():
+    return len(CURRENT_DEBUGGER) > 0
+
+
 import signal  # noqa
 DEFAULT_SIGNAL = signal.SIGINT
 del signal
 
 
-def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
+def runmodule(*args, **kwargs):
+    kwargs["run_as_module"] = True
+    runscript(*args, **kwargs)
+
+
+def runscript(mainpyfile, args=None, pre_run="", steal_output=False,
+              run_as_module=False):
     dbg = _get_debugger(steal_output=steal_output)
 
     # Note on saving/restoring sys.argv: it's a good idea when sys.argv was
@@ -132,7 +120,10 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
     import sys
     if args is not None:
         prev_sys_argv = sys.argv[:]
-        sys.argv = [mainpyfile] + args
+        if run_as_module:
+            sys.argv = args
+        else:
+            sys.argv = [mainpyfile] + args
 
     # replace pudb's dir with script's dir in front of module search path.
     from os.path import dirname
@@ -145,16 +136,24 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
             retcode = call(pre_run, close_fds=True, shell=True)
             if retcode:
                 print("*** WARNING: pre-run process exited with code %d." % retcode)
-                raw_input("[Hit Enter]")
+                input("[Hit Enter]")
 
         status_msg = ""
 
         try:
-            dbg._runscript(mainpyfile)
-        except SystemExit:
-            se = sys.exc_info()[1]
-            status_msg = "The debuggee exited normally with " \
-                    "status code %s.\n\n" % se.code
+            if run_as_module:
+                try:
+                    dbg._runmodule(mainpyfile)
+                except ImportError as e:
+                    print(e, file=sys.stderr)
+                    sys.exit(1)
+            else:
+                try:
+                    dbg._runscript(mainpyfile)
+                except SystemExit:
+                    se = sys.exc_info()[1]
+                    status_msg = "The debuggee exited normally with " \
+                            "status code %s.\n\n" % se.code
         except Exception:
             dbg.post_mortem = True
             dbg.interaction(None, sys.exc_info())
@@ -163,7 +162,7 @@ def runscript(mainpyfile, args=None, pre_run="", steal_output=False):
             import urwid
             pre_run_edit = urwid.Edit("", pre_run)
 
-            if not CONFIG["prompt_on_quit"]:
+            if not load_config()["prompt_on_quit"]:
                 return
 
             result = dbg.ui.call_with_ui(dbg.ui.dialog,
@@ -246,7 +245,7 @@ def _interrupt_handler(signum, frame):
     _get_debugger().set_trace(frame, as_breakpoint=False)
 
 
-def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
+def set_interrupt_handler(interrupt_signal=None):
     """
     Set up an interrupt handler, to activate PuDB when Python receives the
     signal `interrupt_signal`.  By default it is SIGINT (i.e., Ctrl-c).
@@ -266,6 +265,10 @@ def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
 
     Note, this only works when called from the main thread.
     """
+
+    if interrupt_signal is None:
+        interrupt_signal = DEFAULT_SIGNAL
+
     import signal
     old_handler = signal.getsignal(interrupt_signal)
 
@@ -276,7 +279,7 @@ def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
         from warnings import warn
         if old_handler is None:
             # This is the documented meaning of getsignal()->None.
-            old_handler = 'not installed from python'
+            old_handler = "not installed from python"
         return warn("A non-default handler for signal %d is already installed (%s). "
                 "Skipping pudb interrupt support."
                 % (interrupt_signal, old_handler))
@@ -291,11 +294,11 @@ def set_interrupt_handler(interrupt_signal=DEFAULT_SIGNAL):
     try:
         signal.signal(interrupt_signal, _interrupt_handler)
     except ValueError:
-        from pudb.lowlevel import format_exception
+        from traceback import format_exception
         import sys
         from warnings import warn
         warn("setting interrupt handler on signal %d failed: %s"
-                % (interrupt_signal, "".join(format_exception(sys.exc_info()))))
+                % (interrupt_signal, "".join(format_exception(*sys.exc_info()))))
 
 
 def post_mortem(tb=None, e_type=None, e_value=None):
