@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division, print_function
-
 try:
     import bpython  # noqa
     # Access a property to verify module exists in case
@@ -26,14 +24,6 @@ else:
     HAVE_PTPYTHON = True
 
 
-try:
-    import readline
-    import rlcompleter
-    HAVE_READLINE = True
-except ImportError:
-    HAVE_READLINE = False
-
-
 # {{{ combined locals/globals dict
 
 class SetPropagatingDict(dict):
@@ -88,14 +78,21 @@ def run_classic_shell(globals, locals, first_time=[True]):
             get_save_config_path(),
             "shell-history")
 
-    if HAVE_READLINE:
+    try:
+        import readline
+        import rlcompleter
+        have_readline = True
+    except ImportError:
+        have_readline = False
+
+    if have_readline:
         readline.set_completer(
                 rlcompleter.Completer(ns).complete)
         readline.parse_and_bind("tab: complete")
         readline.clear_history()
         try:
             readline.read_history_file(hist_file)
-        except IOError:
+        except OSError:
             pass
 
     from code import InteractiveConsole
@@ -103,7 +100,7 @@ def run_classic_shell(globals, locals, first_time=[True]):
 
     cons.interact(banner)
 
-    if HAVE_READLINE:
+    if have_readline:
         readline.write_history_file(hist_file)
 
 
@@ -146,7 +143,7 @@ def ipython_version():
 
 
 def run_ipython_shell_v10(globals, locals, first_time=[True]):
-    '''IPython shell from IPython version 0.10'''
+    """IPython shell from IPython version 0.10"""
     if first_time:
         banner = "Hit Ctrl-D to return to PuDB."
         first_time.pop()
@@ -162,15 +159,15 @@ def run_ipython_shell_v10(globals, locals, first_time=[True]):
 
 
 def _update_ipython_ns(shell, globals, locals):
-    '''Update the IPython 0.11 namespace at every visit'''
+    """Update the IPython 0.11 namespace at every visit"""
 
     shell.user_ns = locals.copy()
 
     try:
         shell.user_global_ns = globals
     except AttributeError:
-        class DummyMod(object):
-            "A dummy module used for IPython's interactive namespace."
+        class DummyMod:
+            """A dummy module used for IPython's interactive namespace."""
             pass
 
         user_module = DummyMod()
@@ -182,7 +179,7 @@ def _update_ipython_ns(shell, globals, locals):
 
 
 def run_ipython_shell_v11(globals, locals, first_time=[True]):
-    '''IPython shell from IPython version 0.11'''
+    """IPython shell from IPython version 0.11"""
     if first_time:
         banner = "Hit Ctrl-D to return to PuDB."
         first_time.pop()
@@ -227,18 +224,29 @@ def run_ipython_shell_v11(globals, locals, first_time=[True]):
 
 def run_ipython_shell(globals, locals):
     import IPython
-    if have_ipython() and hasattr(IPython, 'Shell'):
+    if have_ipython() and hasattr(IPython, "Shell"):
         return run_ipython_shell_v10(globals, locals)
     else:
         return run_ipython_shell_v11(globals, locals)
 
+
+def run_ipython_kernel(globals, locals):
+    from IPython import embed_kernel
+
+    class DummyMod:
+        pass
+
+    user_module = DummyMod()
+    user_module.__dict__ = globals
+    embed_kernel(module=user_module, local_ns=locals)
+
 # }}}
 
 
 def run_ptpython_shell(globals, locals):
     # Use the default ptpython history
     import os
-    history_filename = os.path.expanduser('~/.ptpython/history')
+    history_filename = os.path.expanduser("~/.ptpython/history")
     ptpython_embed(globals=globals.copy(), locals=locals.copy(),
                    history_filename=history_filename,
                    configure=run_config)
@@ -248,7 +256,7 @@ def run_ptipython_shell(globals, locals):
     # Use the default ptpython history
     import os
 
-    history_filename = os.path.expanduser('~/.ptpython/history')
+    history_filename = os.path.expanduser("~/.ptpython/history")
     ptipython_embed(globals=globals.copy(), locals=locals.copy(),
                    history_filename=history_filename,
                    configure=run_config)
